@@ -97,3 +97,52 @@ def check_supports_list_saved_arrangements(connection):
             "default profile from a Python script. You should upgrade " +
             "to run this script.")
 
+def supports_context_menu_providers(connection):
+    """Can you register a context menu provider?"""
+    min_ver = (1, 7)
+    return ge(connection.iterm2_protocol_version, min_ver)
+
+def check_supports_context_menu_provider(connection):
+    """"Die if context menu providers are not supported."""
+    if not supports_context_menu_providers(connection):
+        raise AppVersionTooOld(
+            "This version of iTerm2 is too old to register a " +
+            "context menu provider. You should upgrade to " +
+            "run this script.")
+
+def supports_add_annotation(connection):
+    """Can you add an annotation?"""
+    min_ver = (1, 8)
+    return ge(connection.iterm2_protocol_version, min_ver)
+
+def check_supports_add_annotation(connection):
+    """Die if you can't add an annotation."""
+    if not supports_add_annotation(connection):
+        raise AppVersionTooOld(
+            "This version of iTerm2 is too old to add an annotation. " +
+            "You should upgrade to run this script.")
+
+def supports_advanced_key_notifications(connection):
+    """Can you get key-up and flags-changed notifs?"""
+    min_ver = (1, 9)
+    return ge(connection.iterm2_protocol_version, min_ver)
+
+def check_supports_advanced_key_notifications(connection):
+    """Die if you can't get key-up and flags-changed notifs."""
+    if not supports_advanced_key_notifications(connection):
+        raise AppVersionTooOld(
+            "This version of iTerm2 is too old to get advanced keystroke " +
+            "notifications. You should upgrade to run this script.")
+
+def supports_file_panels(connection):
+    """"Can you use open/save panels?"""
+    min_ver = (1, 10)
+    return ge(connection.iterm2_protocol_version, min_ver)
+
+def check_supports_file_panels(connection):
+    """"Die if you can't use open/save panels."""
+    if not supports_file_panels(connection):
+        raise AppVersionTooOld(
+            "This version of iTerm2 is too old to use open/save panels." +
+            "You should upgrade to run this script.")
+
